@@ -1,8 +1,8 @@
-context('freq_cont')
+context('ds_freq_cont')
 
-test_that('output from freq_cont matches expected result', {
+test_that('output from ds_freq_cont matches expected result', {
 
-  k <- freq_cont(mtcars$mpg, bins = 4)
+  k <- ds_freq_cont(mtcars$mpg, bins = 4)
   expect_equivalent(k$breaks, c(10.400, 16.275, 22.150, 28.025, 33.900))
   expect_equivalent(k$frequency, c(10, 13, 5, 4))
   expect_equivalent(k$cumulative, c(10, 23, 28, 32))
@@ -14,10 +14,10 @@ test_that('output from freq_cont matches expected result', {
 
 })
 
-test_that('freq_cont returns appropriate errors', {
+test_that('ds_freq_cont returns appropriate errors', {
 
-  expect_error(freq_cont('mtcars$mpg'), 'data must be numeric')
-  expect_error(freq_cont(as.factor(mtcars$mpg)), 'data must be numeric')
-  expect_error(freq_cont(mtcars$mpg, '5'), 'bins must be integer value')
+  expect_error(ds_freq_cont('mtcars$mpg'), 'data must be numeric')
+  expect_error(ds_freq_cont(as.factor(mtcars$mpg)), 'data must be numeric')
+  expect_error(ds_freq_cont(mtcars$mpg, '5'), 'bins must be integer value')
 
 })
